# aicastle
AI Castle Package

homepage : https://aicastle.io
email : dev@aicastle.io

## Installation
```
python -m pip install aicastle
```

## upgrade
```
python -m pip install --upgrade aicastle
```